@@ -6,8 +6,8 @@ ATTR_GROUP = "Group"
 ATTR_ID = "Id"
 ATTR_READ_ONLY = "Read_only"
 ATTR_RELE = "Rele"
-ATTR_SWITCH_OFF = "0"
-ATTR_SWITCH_ON = "1"
+ATTR_SWITCH_OFF = 0
+ATTR_SWITCH_ON = 1
 ATTR_TEMP = "Temp"
 ATTR_TEMP_SET = "Temp_set"
 ATTR_TITLE = "Title"
@@ -17,6 +17,7 @@ ATTR_UP = "Up"
 # Internal device attributes
 ATTR_SWITCH = "switch"
 ATTR_LIGHT = "light"
+ATTR_DOOR = "door"
 ATTR_SHUTTER = "shutter"
 ATTR_HEATING = "heating"
 ATTR_THERM = "therm"
@@ -30,7 +31,8 @@ DEVICE_TYPE_DICT = {
     "shutters": "shutter",
     "heat-control": "therm",
     "heating": "heating",
-    "garage": "garage"
+    "garage": "door",
+    "gate": "door"
 }
 
 INELS_BUS_ATTR_DICT = {
@@ -56,4 +58,17 @@ SUPPORT_RGB_COLOR = 2
 SUPPORT_COLOR_TEMP = 4
 SUPPORT_HEX_COLOR = 8
 
-VERSION = "0.5.2"
+# supported features
+SUPPORT_OPEN = 1
+SUPPORT_CLOSE = 2
+SUPPORT_STOP = 8
+SUPPORT_OPEN_TILT = 16
+SUPPORT_CLOSE_TILT = 32
+SUPPORT_STOP_TILT = 64
+
+STATE_OPEN = "open"
+STATE_OPENING = "opening"
+STATE_CLOSED = "closed"
+STATE_CLOSING = "closing"
+
+VERSION = "0.5.6"
